@@ -6,6 +6,7 @@ pub use loom::sync::atomic::*;
 
 /// atomic store with assertion on old_val equals to the one of atomic
 /// before storing new_val under debug mode.
+#[inline(always)]
 pub fn assert_store_ptr<T>(
     atomic: &AtomicPtr<T>,
     _old_val: *mut T,
@@ -14,7 +15,7 @@ pub fn assert_store_ptr<T>(
     release_order: Ordering
 ) {
     #[cfg(debug)]
-    assert!(ptr::eq(_old_val, atomic.swap(new_val, _debug_order)));
+    assert_eq!(_old_val, atomic.swap(new_val, _debug_order));
     #[cfg(not(debug))]
     atomic.store(new_val, release_order);
 }
