@@ -12,11 +12,17 @@ pub use state_storage::*;
 mod state_sync {
     pub use std::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard, LockResult, TryLockResult};
 
-    pub fn obtain_read_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockReadGuard<'_, T>> {
+    #[inline(always)]
+    pub fn obtain_read_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockReadGuard<'_, T>>
+    {
         rwlock.read()
     }
 
-    pub fn obtain_write_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockWriteGuard<'_, T>> {
+    #[inline(always)]
+    pub fn obtain_write_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockWriteGuard<'_, T>>
+    {
         rwlock.write()
     }
 
@@ -43,11 +49,17 @@ mod state_sync {
     pub type LockResult<T> = Result<T, ()>;
     pub type TryLockResult<T> = Result<T, tokio::sync::TryLockError>;
 
-    pub async fn obtain_read_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockReadGuard<'_, T>> {
+    #[inline(always)]
+    pub async fn obtain_read_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockReadGuard<'_, T>>
+    {
         Ok(rwlock.read().await)
     }
 
-    pub async fn obtain_write_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockWriteGuard<'_, T>> {
+    #[inline(always)]
+    pub async fn obtain_write_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockWriteGuard<'_, T>>
+    {
         Ok(rwlock.write().await)
     }
 
@@ -72,11 +84,17 @@ mod state_sync {
 mod state_sync {
     pub use loom::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard, LockResult, TryLockResult};
 
-    pub fn obtain_read_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockReadGuard<'_, T>> {
+    #[inline(always)]
+    pub fn obtain_read_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockReadGuard<'_, T>>
+    {
         rwlock.read()
     }
 
-    pub fn obtain_write_lock<T>(rwlock: &RwLock<T>) -> LockResult<RwLockWriteGuard<'_, T>> {
+    #[inline(always)]
+    pub fn obtain_write_lock<T>(rwlock: &RwLock<T>)
+        -> LockResult<RwLockWriteGuard<'_, T>>
+    {
         rwlock.write()
     }
 
